import React from 'react';
import Animated, { useAnimatedStyle } from 'react-native-reanimated';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import IonIcon from 'react-native-vector-icons/Ionicons';
import { useTheme } from '../services/ThemeContext';
//
// HOCs
//
function makeAnimatedFontIcon(IconComponent, name) {
    return (props) => {
        const { accessible, color, size } = props;
        const { icon, rem } = useTheme();
        const oneRem = rem(1);
        const style = useAnimatedStyle(() => {
            var _a, _b;
            return ({
                color: (_a = color === null || color === void 0 ? void 0 : color.value) !== null && _a !== void 0 ? _a : icon,
                fontSize: (_b = size === null || size === void 0 ? void 0 : size.value) !== null && _b !== void 0 ? _b : oneRem
            });
        });
        return (React.createElement(IconComponent, { accessible: accessible, name: name, adjustsFontSizeToFit: true, style: style }));
    };
}
function makeFontIcon(IconComponent, name) {
    return (props) => {
        const { icon, rem } = useTheme();
        const { accessible, color = icon, size = rem(1) } = props;
        const style = {
            color: color,
            fontSize: size
        };
        return (React.createElement(IconComponent, { accessible: accessible, name: name, adjustsFontSizeToFit: true, style: style }));
    };
}
//
// Font Icons
//
const AnimatedAntDesignIcon = Animated.createAnimatedComponent(AntDesignIcon);
const AnimatedIonIcon = Animated.createAnimatedComponent(IonIcon);
export const CloseIcon = makeFontIcon(AntDesignIcon, 'close');
export const CloseIconAnimated = makeAnimatedFontIcon(AnimatedAntDesignIcon, 'close');
export const EyeIcon = makeFontIcon(IonIcon, 'eye-outline');
export const EyeIconAnimated = makeAnimatedFontIcon(AnimatedIonIcon, 'eye-outline');
export const EyeOffIcon = makeFontIcon(IonIcon, 'eye-off-outline');
export const EyeOffIconAnimated = makeAnimatedFontIcon(AnimatedIonIcon, 'eye-off-outline');
export const SearchIcon = makeFontIcon(AntDesignIcon, 'search1');
export const SearchIconAnimated = makeAnimatedFontIcon(AnimatedAntDesignIcon, 'search1');
